@@ -2,13 +2,15 @@
 Date         : 2023-11-02 17:34:28
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-11-13 11:34:28
+LastEditTime : 2023-11-13 15:45:22
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\eda\__init__.py
 Copyright (c) 2023 by BDFD, All Rights Reserved. 
 '''
 from ._data_mining import high_miss_rate_column
+from ._data_mining import numerical_features_list
+from ._data_mining import categorical_features_list
 from ._data_mining import column_identify
 from ._data_mining import filtered_value_count
 from ._data_mining import filtered_value_list
